@@ -1,8 +1,9 @@
 import React from 'react';
+import { DataSourceSettings } from '@grafana/data';
 
 import { DataSourceHttpSettings } from './DataSourceHttpSettings';
-import { DataSourceSettings } from '@grafana/data';
 import { UseState } from '../../utils/storybook/UseState';
+import mdx from './DataSourceHttpSettings.mdx';
 
 const settingsMock: DataSourceSettings<any, any> = {
   id: 4,
@@ -24,16 +25,23 @@ const settingsMock: DataSourceSettings<any, any> = {
     timeInterval: '15s',
     httpMode: 'GET',
     keepCookies: ['cookie1', 'cookie2'],
+    serverName: '',
   },
   secureJsonData: {
     password: true,
   },
+  secureJsonFields: {},
   readOnly: true,
 };
 
 export default {
   title: 'Data Source/DataSourceHttpSettings',
   component: DataSourceHttpSettings,
+  parameters: {
+    docs: {
+      page: mdx,
+    },
+  },
 };
 
 export const basic = () => {
