@@ -2,7 +2,7 @@ import React from 'react';
 import { action } from '@storybook/addon-actions';
 import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
 import { UseState } from '../../utils/storybook/UseState';
-import { RefreshPicker } from './RefreshPicker';
+import { RefreshPicker } from '@grafana/ui';
 
 export default {
   title: 'Pickers and Editors/RefreshPicker',
@@ -19,7 +19,7 @@ export const basic = () => {
             tooltip="Hello world"
             value={value}
             intervals={['5s', '10s', '30s', '1m', '5m', '15m', '30m', '1h', '2h', '1d']}
-            onIntervalChanged={interval => {
+            onIntervalChanged={(interval) => {
               action('onIntervalChanged fired')(interval);
             }}
             onRefresh={() => {
